Hospital Outpatient Activity 2023-24 - NHS England Digital

Skip to main content

Publication, Part of Hospital Outpatient Activity

# Hospital Outpatient Activity 2023-24

National statistics, Accredited official statistics

Publication Date:
  26 Sep 2024
Geographic Coverage:
  England
Geographical Granularity:
  Strategic Health Authorities, Hospital Trusts, Independent Sector Health Care Providers, Regions, NHS Trusts, Country
Date Range:
  01 Apr 2023 to 31 Mar 2024

## Summary

This publication reports on Outpatient activity in England for the financial year 2023-24.

This report includes but is not limited to analysis of hospital outpatient appointments by patient demographics, diagnoses, attendance type, operations, specialty and provider level analysis. It describes NHS outpatient appointments in England, rather than the number of patients. The purpose of this publication is to inform and support strategic and policy-led processes for the benefit of patient care and may also be of interest to researchers, journalists and members of the public interested in NHS hospital activity in England.

The data source for this publication is Hospital Episode Statistics (HES), which come from the HES data warehouse containing details of all admissions and outpatient appointments at National Health Service (NHS) hospitals in England. It includes private patients treated in NHS hospitals, patients who were resident outside of England and care delivered by treatment centres (including those in the independent sector) funded by the NHS.

Please send queries or feedback via email to [email protected]. Author: Secondary Care Open Data and Publications, NHS England. Lead Analyst: Karl Eichler.

## Highlights

Number of Outpatient Appointments

In 2023-24, there were 135.4 million outpatient appointments.

This is an increase of 8.8% from the published figure for the previous year, and an 8.4% increase from the level seen before the coronavirus (COVID-19) pandemic (there were 124.9 million appointments in 2019-20).

Please note that the published number of appointments for 2022-23 are estimated to have been 1.3 million records less than the actual level of activity, as one provider was unable to submit data between June 2022 and March 2023.

Number of Outpatient Attendances

In 2023-24, there were 104.6 million outpatient attendances.

This is an increase of 9.1% from the published figure for the previous year, and an 8.5% increase from the level seen before the coronavirus (COVID-19) pandemic (there were 96.4 million attendances in 2019-20).

Please note that the published number of attendances for 2022-23 are estimated to have been 1.0 million records less than the actual level of activity, as one provider was unable to submit data between June 2022 and March 2023.

Number of 'Did Not Attends' for outpatient appointments

In 2023-24, 8.0 million outpatient appointments were DNAs.

This is an increase of 0.2% from the previous year.

## Key Facts

## Interactive Tool

## Provider Level Analysis - 2023-24

This dashboard includes Hospital Outpatient Activity at national, regional and provider level for measures included in the publication. The data source is the provider level analysis open data file in this publication.

## Resources

Hospital Outpatient Activity, 2023-24: Report Tables

xlsx 126 KB

Hospital Outpatient Activity, 2023-24: All Attendances

xlsx 115 KB

Hospital Outpatient Activity, 2023-24: First Attendances

xlsx 124 KB

Hospital Outpatient Activity, 2023-24: Main Procedure or Intervention

xlsx 339 KB

Hospital Outpatient Activity, 2023-24: Primary Diagnosis

xlsx 594 KB

Hospital Outpatient Activity, 2023-24: Main Speciality

xlsx 62 KB

Hospital Outpatient Activity, 2023-24: Treatment Speciality

xlsx 70 KB

Hospital Outpatient Activity, 2023-24: Ethnic Category

xlsx 55 KB

Hospital Outpatient Activity, 2023-24: Index of Multiple Deprivation (IMD)

xlsx 56 KB

Hospital Outpatient Activity, 2023-24: All Attendances and First Attendances data

csv 1 MB

Hospital Outpatient Activity, 2023-24: Main Procedure or Intervention and Primary Diagnosis data

csv 7 MB

Hospital Outpatient Activity, 2023-24: Main Speciality and Treatment Speciality data

csv 194 KB

Hospital Outpatient Activity, 2023-24: Ethnic Category and Index of Multiple Deprivation (IMD) data

xlsx 56 KB

Hospital Outpatient Activity, 2023-24: Provider Level Analysis

csv 6 MB

Hospital Outpatient Activity, 2023-24: Metadata

xlsx 80 KB

Pre-Release Access List

pdf 104 KB
ARTICLE

HES Supporting Information

## Related Links

- Hospital Accident and Emergency Activity 2023-24
- Hospital Admitted Patient Care Activity 2023-24
- HES Data Quality

Last edited: 15 September 2025 12:44 pm

Next Chapter

About this publication

## Pages in this publication